Unicode.IndicSyllabicCategory (Unicode v1.21.0)

Functions to introspect Unicode indic syllabic categories for binaries (Strings) and codepoints.

Summary

Functions

Returns a map of aliases for Unicode indic syllabic categorys.

Returns the count of the number of characters for a given indic syllabic category.

Returns the Unicode ranges for a given indic syllabic category as a list of ranges as 2-tuples.

Returns the Unicode ranges for a given indic syllabic category as a list of ranges as 2-tuples.

Returns the map of Unicode indic syllabic categorys.

Returns the indic syllabic category name(s) for the given binary or codepoint.

Returns a list of known Unicode indic syllabic category names.

Functions

aliases()

Returns a map of aliases for Unicode indic syllabic categorys.

An alias is an alternative name for referring to a indic syllabic category. Aliases are resolved by the fetch/1 and get/1 functions.

count(indic_syllabic_category)

Returns the count of the number of characters for a given indic syllabic category.

Example

iex> Unicode.IndicSyllabicCategory.count(:bindu)
99

fetch(indic_syllabic_category)

Returns the Unicode ranges for a given indic syllabic category as a list of ranges as 2-tuples.

Aliases are resolved by this function.

Returns either {:ok, range_list} or :error.

get(indic_syllabic_category)

Returns the Unicode ranges for a given indic syllabic category as a list of ranges as 2-tuples.

Aliases are resolved by this function.

Returns either range_list or nil.

indic_syllabic_categories()

Returns the map of Unicode indic syllabic categorys.

The indic syllabic category name is the map key and a list of codepoint ranges as tuples as the value.

indic_syllabic_category(string)

Returns the indic syllabic category name(s) for the given binary or codepoint.

In the case of a codepoint, a single indic syllabic category name is returned.

For a binary a list of distinct indic syllabic category names represented by the lines in the binary is returned.

known_indic_syllabic_categories()

Returns a list of known Unicode indic syllabic category names.

This function does not return the names of any indic syllabic category aliases.